@@ -90,7 +90,7 @@ class FacialRecognitionClient:
                         self.server_base_url = f"http://localhost:{server_port}"
                         self.logger.warning(f"Server host matches public IP, using localhost: {self.server_base_url}")
                     else:
-                        self.server_base_url = f"https://{server_host}:{server_port}"
+                        self.server_base_url = f"http://{server_host}:{server_port}"
                         self.logger.warning(f"Facial recognition server base URL: {self.server_base_url}")
                     
                     self.session.update(self.server_info.get('projectID', ''))
