@@ -29,6 +29,7 @@ import logging
 import asyncio
 import urllib
 import urllib.request
+import base64
 # Get the major and minor version numbers
 major_version = sys.version_info.major
 minor_version = sys.version_info.minor
@@ -285,8 +286,17 @@ class LicensePlateMonitorLogger:
             self.logger.warning(f"Failed to parse timestamp '{timestamp}': {e}. Using current time.")
             return datetime.now(timezone.utc).strftime('%Y-%m-%dT%H:%M:%SZ')
 
-    async def log_plate(self, plate_text: str, timestamp: str, stream_info: Dict[str, Any], cooldown: float = 30.0) -> bool:
-        """Log plate to RPC server with cooldown period."""
+    async def log_plate(self, plate_text: str, timestamp: str, stream_info: Dict[str, Any], 
+                       image_data: Optional[str] = None, cooldown: float = 30.0) -> bool:
+        """Log plate to RPC server with cooldown period.
+        
+        Args:
+            plate_text: The license plate text
+            timestamp: Capture timestamp
+            stream_info: Stream information dict
+            image_data: Base64-encoded JPEG image of the license plate crop
+            cooldown: Cooldown period in seconds
+        """
         self.logger.info(f"Attempting to log plate: {plate_text} at {timestamp}")
         
         # Check cooldown
@@ -312,12 +322,13 @@ class LicensePlateMonitorLogger:
                 'location': location,
                 'camera': camera_name,
                 'captureTimestamp': rfc3339_timestamp,
-                'projectId': project_id
+                'projectId': project_id,
+                'imageData': image_data if image_data else ""
             }
             
             # Add projectId as query parameter
             endpoint = f'/v1/lpr-server/detections?projectId={project_id}'
-            self.logger.info(f"Sending POST request to {self.server_base_url}{endpoint} with payload: {payload}")
+            self.logger.info(f"Sending POST request to {self.server_base_url}{endpoint} with plate: {plate_text}, imageData length: {len(image_data) if image_data else 0}")
             
             response = await self.session.rpc.post_async(endpoint, payload=payload, base_url=self.server_base_url)
             
@@ -450,7 +461,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             self._logging_enabled = False
     
     def _log_detected_plates(self, detections: List[Dict[str, Any]], config: LicensePlateMonitorConfig, 
-                            stream_info: Optional[Dict[str, Any]]) -> None:
+                            stream_info: Optional[Dict[str, Any]], image_bytes: Optional[bytes] = None) -> None:
         """Log all detected plates to RPC server with cooldown."""
         if not self._logging_enabled or not self.plate_logger or not stream_info:
             return
@@ -458,6 +469,24 @@ class LicensePlateMonitorUseCase(BaseProcessor):
         # Get current timestamp
         current_timestamp = self._get_current_timestamp_str(stream_info, precision=True)
         
+        # Encode the full frame image as base64 JPEG
+        image_data = ""
+        if image_bytes:
+            try:
+                # Decode image bytes
+                image_array = np.frombuffer(image_bytes, np.uint8)
+                image = cv2.imdecode(image_array, cv2.IMREAD_COLOR)
+                
+                if image is not None:
+                    # Encode as JPEG with 85% quality
+                    success, jpeg_buffer = cv2.imencode('.jpg', image, [cv2.IMWRITE_JPEG_QUALITY, 99])
+                    if success:
+                        # Convert to base64
+                        image_data = base64.b64encode(jpeg_buffer.tobytes()).decode('utf-8')
+                        self.logger.debug(f"Encoded frame image as base64, length: {len(image_data)}")
+            except Exception as e:
+                self.logger.error(f"Failed to encode frame image: {e}")
+        
         # Collect all unique plates from current detections
         plates_to_log = set()
         for det in detections:
@@ -479,6 +508,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
                             plate_text=plate_text,
                             timestamp=current_timestamp,
                             stream_info=stream_info,
+                            image_data=image_data,
                             cooldown=config.plate_log_cooldown
                         )
                         tasks.append(task)
@@ -606,7 +636,7 @@ class LicensePlateMonitorUseCase(BaseProcessor):
             self._update_plate_texts(processed_data)
             
             # Step 9.5: Log detected plates to RPC (optional, only if lpr_server_id is provided)
-            self._log_detected_plates(processed_data, config, stream_info)
+            self._log_detected_plates(processed_data, config, stream_info, input_bytes)
             
             # Step 10: Update frame counter
             self._total_frame_counter += 1
